#[non_exhaustive]pub struct Residuals {
pub max_active_power_mismatch: Option<f64>,
pub max_reactive_power_mismatch: Option<f64>,
}Expand description
Numerical residuals of the solved equations, in the problem’s power unit.
A field is None when the producer did not report it.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.max_active_power_mismatch: Option<f64>Largest absolute active power balance mismatch, MW.
max_reactive_power_mismatch: Option<f64>Largest absolute reactive power balance mismatch, MVAr.