SocwrOpfSolution

Struct SocwrOpfSolution 

pub struct SocwrOpfSolution { /* private fields */ }
A solution of the PowerModels SOCWR relaxation of AC optimal power flow.

This is a relaxation result and its objective is a lower bound. It is not an crate::AcOpfSolution and makes no claim that its voltage products recover an AC feasible voltage phasor.

Implementations

Source

impl SocwrOpfSolution

pub const FORMULATION: &'static str = "socwr"

pub fn new( instance: Arc<AcOpfInstance>, termination: Termination, values: SocwrOpfValues, objective_lower_bound: f64, ) -> Result<Self, Error>

Construct a SOCWR solution from table ordered primal values and its objective lower bound.

Errors

Any value column has a length different from its network table.

pub const fn formulation(&self) -> &'static str

pub fn instance(&self) -> &AcOpfInstance

pub fn shared_instance(&self) -> Arc<AcOpfInstance>

pub fn network(&self) -> &BalancedNetwork

pub const fn termination(&self) -> &Termination

pub const fn residuals(&self) -> &Residuals

pub fn producer(&self) -> Option<&str>

pub const fn values(&self) -> &SocwrOpfValues

pub const fn duals(&self) -> &SocwrOpfDuals

pub const fn objective_lower_bound(&self) -> f64

pub fn with_producer(self, producer: impl Into<String>) -> Self

pub const fn with_residuals(self, residuals: Residuals) -> Self

pub fn with_duals(self, duals: SocwrOpfDuals) -> Result<Self, Error>

Attach optional dual columns.

Errors

A present column has the wrong length, or a thermal limit multiplier is negative or nonfinite.

pub fn bus_order(&self) -> impl ExactSizeIterator<Item = BusId> + '_

pub fn branch_order(&self) -> impl ExactSizeIterator<Item = String> + '_

pub fn generator_order(&self) -> impl ExactSizeIterator<Item = String> + '_

pub fn bus_voltage_magnitude_squared(&self, bus: BusId) -> Option<f64>

pub fn branch_voltage_product_real(&self, branch: &str) -> Option<f64>

pub fn branch_voltage_product_imaginary(&self, branch: &str) -> Option<f64>

pub fn generator_active_power(&self, generator: &str) -> Option<f64>

pub fn generator_reactive_power(&self, generator: &str) -> Option<f64>

pub fn branch_from_active_power(&self, branch: &str) -> Option<f64>

pub fn branch_from_reactive_power(&self, branch: &str) -> Option<f64>

pub fn branch_to_active_power(&self, branch: &str) -> Option<f64>

pub fn branch_to_reactive_power(&self, branch: &str) -> Option<f64>